@@ -546,6 +546,25 @@ class AbbreviationsTest {
         assertThat(sgroups.size(), is(0));
     }
 
+    @Test
+    void testAc() throws Exception {
+        Abbreviations factory = new Abbreviations();
+        IAtomContainer mol = smi("[nH]1ccc2c1cc(OC(=O)C)cc2");
+        factory.add("*OC(=O)C OAc");
+        factory.add("*C(=O)C Ac");
+        List<Sgroup> sgroups = factory.generate(mol);
+        assertThat(sgroups.size(), is(1));
+        Assertions.assertEquals("OAc", sgroups.get(0).getSubscript());
+        Map<IAtom,Integer> aset = new HashMap<>();
+        aset.put(mol.getAtom(7), 1); // -O-
+        aset.put(mol.getAtom(8), 2); // CH
+        aset.put(mol.getAtom(9), 2); // =O
+        aset.put(mol.getAtom(10), 2); // Me
+        sgroups = factory.generate(mol, aset);
+        assertThat(sgroups.size(), is(1));
+        Assertions.assertEquals("Ac", sgroups.get(0).getSubscript());
+    }
+
     @Test
     void TFASaltDisconnected() throws Exception {
         Abbreviations factory = new Abbreviations();
@@ -800,6 +819,30 @@ class AbbreviationsTest {
         assertThat(sgroups.get(0).getSubscript(), is("HOOH"));
     }
 
+    @Test
+    void shouldNotPartiallyContractKetene() throws Exception {
+        Abbreviations factory = new Abbreviations();
+        IAtomContainer mol = smi("c1ccccc1CC=C=O");
+        factory.with(Abbreviations.Option.AUTO_CONTRACT_HETERO);
+        factory.with(Abbreviations.Option.AUTO_CONTRACT_TERMINAL);
+        List<Sgroup> sgroups = factory.generate(mol);
+        assertThat(sgroups.size(), is(0));
+    }
+
+    @Test
+    void testAttachments() throws Exception {
+        IAtomContainer mol = smi("*C(=O)OCCC");
+        Abbreviations factory = new Abbreviations();
+        factory.with(Abbreviations.Option.AUTO_CONTRACT_TERMINAL);
+        factory.with(Abbreviations.Option.AUTO_CONTRACT_HETERO);
+        factory.with(Abbreviations.Option.AUTO_CONTRACT_LINKERS);
+        List<Sgroup> sgroups = factory.generate(mol);
+        assertThat(sgroups.size(), is(1));
+        assertThat(sgroups.get(0).getSubscript(), is("CO"));
+        assertThat(sgroups.get(0).getBonds().size(), is(2));
+    }
+
+
     @Test
     void multipleDisconnectedAbbreviations() throws Exception {
         String smi = "ClCCl.Cl[Pd]Cl.[Fe+2].c1ccc(P([c-]2cccc2)c2ccccc2)cc1.c1ccc(P([c-]2cccc2)c2ccccc2)cc1";
@@ -826,11 +869,22 @@ class AbbreviationsTest {
         assertThat(sgroups.get(0).getSubscript(), is("Pd(dppf)Cl2"));
     }
 
+    @Test
+    void keepIsotopes() throws Exception {
+        String smi = "c1ccccc1C#[15N]";
+        Abbreviations factory = new Abbreviations();
+        factory.add("*C#N CN");
+        factory.with(Abbreviations.Option.AUTO_CONTRACT_TERMINAL);
+        factory.with(Abbreviations.Option.AUTO_CONTRACT_HETERO);
+        IAtomContainer mol = smi(smi);
+        List<Sgroup> sgroups = factory.generate(mol);
+        assertThat(sgroups.size(), is(0));
+    }
+
     @Test
     void loadFromFile() throws Exception {
         Abbreviations factory = new Abbreviations();
         assertThat(factory.loadFromFile("obabel_superatoms.smi"), is(27));
         assertThat(factory.loadFromFile("/org/openscience/cdk/depict/obabel_superatoms.smi"), is(27));
     }
-
 }
