@@ -34,8 +34,6 @@ import org.openscience.cdk.interfaces.IBond;
  *   IBond.Order singleBondOrder = CDKConstants.BONDORDER_SINGLE;
  * </pre>
  *
- * @cdk.module  core
- * @cdk.githash
  *
  * @cdk.keyword bond order
  * @cdk.keyword stereochemistry
@@ -415,6 +413,7 @@ public class CDKConstants {
      */
     public static final Object      Z_ORDER                      = "cdk:ZOrder";
 
+
     /* **************************************
      * Some predefined property names for * Atoms *
      * **************************************
@@ -488,6 +487,13 @@ public class CDKConstants {
     public static final String      REACTION_ARROW                = "cdk:Arrow";
 
 
+    /**
+     * Bounds object for when an IChemObject has been generated by
+     * another generator.
+     */
+    public static final Object      RENDER_BOUNDS                 =  "cdk:RenderBounds";
+
+
     /* **************************************
      * Some predefined property names for * AtomTypes *
      * **************************************
