@@ -23,8 +23,6 @@ package org.openscience.cdk.interfaces;
  * implementation.
  *
  * @author        egonw
- * @cdk.module    interfaces
- * @cdk.githash
  */
 public interface IChemObjectBuilder {
 
@@ -79,4 +77,15 @@ public interface IChemObjectBuilder {
      */
     IReaction newReaction();
 
+    /**
+     * This function is used to find an IChemObject builder using reflection. It
+     * first tries to create a SilentChemObjectBuilder and failing that a
+     * DefaultChemObjectBuilder. It should be used sparingly since APIs should
+     * require a builder is passed in.
+     *
+     * @return the IChemObject builder
+     */
+    static IChemObjectBuilder find() {
+        return ChemObjectBuilderCache.INSTANCE.get();
+    }
 }
