@@ -23,7 +23,8 @@
 
 package org.openscience.cdk.stereo;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.mockito.Mockito;
 import org.openscience.cdk.exception.InvalidSmilesException;
 import org.openscience.cdk.interfaces.IAtom;
@@ -38,15 +39,15 @@ import java.util.Iterator;
 import static org.hamcrest.CoreMatchers.instanceOf;
 import static org.hamcrest.CoreMatchers.is;
 import static org.hamcrest.MatcherAssert.assertThat;
-import static org.junit.Assert.assertTrue;
 
-public class TrigonalBipyramidalTest {
+class TrigonalBipyramidalTest {
 
-    @Test public void normalize() throws InvalidSmilesException {
+    @Test
+    void normalize() throws InvalidSmilesException {
         SmilesParser             smipar = new SmilesParser(SilentChemObjectBuilder.getInstance());
         IAtomContainer           mol    = smipar.parseSmiles("C[As@TB3](Cl)(Cl)(C)Cl");
         Iterator<IStereoElement> ses    = mol.stereoElements().iterator();
-        assertTrue(ses.hasNext());
+        Assertions.assertTrue(ses.hasNext());
         IStereoElement se = ses.next();
         assertThat(se, instanceOf(TrigonalBipyramidal.class));
         assertThat(se.getConfigOrder(), is(3));
@@ -61,26 +62,32 @@ public class TrigonalBipyramidalTest {
         )));
     }
 
-    @Test(expected = IllegalArgumentException.class)
-    public void tooManyCarriers() {
-        IAtom a0 = Mockito.mock(IAtom.class);
-        IAtom a1 = Mockito.mock(IAtom.class);
-        IAtom a2 = Mockito.mock(IAtom.class);
-        IAtom a3 = Mockito.mock(IAtom.class);
-        IAtom a4 = Mockito.mock(IAtom.class);
-        IAtom a5 = Mockito.mock(IAtom.class);
-        IAtom a6 = Mockito.mock(IAtom.class);
-        new TrigonalBipyramidal(a0, new IAtom[]{a1,a2,a3,a4,a5,a6}, 1);
+    @Test
+    void tooManyCarriers() {
+        Assertions.assertThrows(IllegalArgumentException.class,
+                                () -> {
+                                    IAtom a0 = Mockito.mock(IAtom.class);
+                                    IAtom a1 = Mockito.mock(IAtom.class);
+                                    IAtom a2 = Mockito.mock(IAtom.class);
+                                    IAtom a3 = Mockito.mock(IAtom.class);
+                                    IAtom a4 = Mockito.mock(IAtom.class);
+                                    IAtom a5 = Mockito.mock(IAtom.class);
+                                    IAtom a6 = Mockito.mock(IAtom.class);
+                                    new TrigonalBipyramidal(a0, new IAtom[]{a1, a2, a3, a4, a5, a6}, 1);
+                                });
     }
 
-    @Test(expected = IllegalArgumentException.class)
-    public void badConfigurationOrder() {
-        IAtom a0 = Mockito.mock(IAtom.class);
-        IAtom a1 = Mockito.mock(IAtom.class);
-        IAtom a2 = Mockito.mock(IAtom.class);
-        IAtom a3 = Mockito.mock(IAtom.class);
-        IAtom a4 = Mockito.mock(IAtom.class);
-        IAtom a5 = Mockito.mock(IAtom.class);
-        new TrigonalBipyramidal(a0, new IAtom[]{a1,a2,a3,a4,a5}, 32);
+    @Test
+    void badConfigurationOrder() {
+        Assertions.assertThrows(IllegalArgumentException.class,
+                                () -> {
+                                    IAtom a0 = Mockito.mock(IAtom.class);
+                                    IAtom a1 = Mockito.mock(IAtom.class);
+                                    IAtom a2 = Mockito.mock(IAtom.class);
+                                    IAtom a3 = Mockito.mock(IAtom.class);
+                                    IAtom a4 = Mockito.mock(IAtom.class);
+                                    IAtom a5 = Mockito.mock(IAtom.class);
+                                    new TrigonalBipyramidal(a0, new IAtom[]{a1, a2, a3, a4, a5}, 32);
+                                });
     }
 }
