@@ -22,19 +22,18 @@
  */
 package org.openscience.cdk.fingerprint;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 import static org.hamcrest.CoreMatchers.is;
 
-public class IntArrayFingerprintTest extends AbstractBitFingerprintTest {
+class IntArrayFingerprintTest extends AbstractBitFingerprintTest {
 
-    public IntArrayFingerprintTest() throws Exception {
+    IntArrayFingerprintTest() throws Exception {
         super(IntArrayFingerprint.class);
     }
 
     @Test
-    public void testSetBit() {
+    void testSetBit() {
         IntArrayFingerprint fp = new IntArrayFingerprint();
         fp.set(1, true);
         fp.set(55, true);
