@@ -24,7 +24,7 @@
 package org.openscience.cdk.geometry.surface;
 
 import org.hamcrest.CoreMatchers;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IChemFile;
@@ -40,10 +40,10 @@ import java.util.Map;
 
 import static org.hamcrest.MatcherAssert.assertThat;
 
-public class NumericalSurfaceTest {
+class NumericalSurfaceTest {
 
     @Test
-    public void testCranbinSurface() throws Exception {
+    void testCranbinSurface() throws Exception {
         IChemObjectBuilder bldr = SilentChemObjectBuilder.getInstance();
         IChemFile chemFile;
         String path = "1CRN.pdb";
