@@ -47,8 +47,6 @@ import org.openscience.cdk.renderer.selection.IChemObjectSelection;
  * Model for {@link IRenderer} that contains settings for drawing objects.
  *
  * @author maclean
- * @cdk.module render
- * @cdk.githash
  */
 public class RendererModel implements Serializable, Cloneable {
 
@@ -325,6 +323,7 @@ public class RendererModel implements Serializable, Cloneable {
     public void setHighlightedAtom(IAtom highlightedAtom) {
         if ((this.highlightedAtom != null) || (highlightedAtom != null)) {
             this.highlightedAtom = highlightedAtom;
+            this.highlightedBond = null;
             fireChange();
         }
     }
@@ -347,6 +346,7 @@ public class RendererModel implements Serializable, Cloneable {
     public void setHighlightedBond(IBond highlightedBond) {
         if ((this.highlightedBond != null) || (highlightedBond != null)) {
             this.highlightedBond = highlightedBond;
+            this.highlightedAtom = null;
             fireChange();
         }
     }
