@@ -91,10 +91,10 @@ final class AbbreviationLabel {
     //    OTHER DEALINGS IN THE SOFTWARE.
     //
     //    For more information, please refer to <http://unlicense.org/>
-    private final static String[] SYMBOL_LIST = new String[]{"acac", "Ace", "Acetyl", "Acyl", "Ad", "All", "Alloc", "Allyl", "Amyl", "AOC",
-                                                             "BDMS", "Benzoyl", "Benzyl", "Bn", "BOC", "Boc", "BOM", "bpy", "Bromo", "Bs", "Bu", "But", "Butyl", "Bz", "Bzl",
+    private final static String[] SYMBOL_LIST = new String[]{"acac", "amphos", "Ace", "Acetyl", "Acyl", "Ad", "All", "Alloc", "Allyl", "Amyl", "AOC",
+                                                             "BDMS", "Benzoyl", "Benzyl", "Bn", "BOC", "Boc", "BOM", "bpy", "Bromo", "Bs", "BPin", "Bpin", "Bu", "But", "Butyl", "Bz", "Bzl",
                                                              "Car", "Cbz", "Chloro", "CoA", "Cy",
-                                                             "dppf", "dppp", "dba", "D", "Dan", "Dansyl", "DEIPS", "DEM", "Dip", "Dmb", "DPA", "DTBMS",
+                                                             "dppf", "dppp", "dba", "dtbpf", "D", "Dan", "Dansyl", "DEIPS", "DEM", "Dip", "Dmb", "DPA", "DTBMS",
                                                              "EE", "EOM", "Et", "Ethyl",
                                                              "Fluoro", "FMOC", "Fmoc", "Formyl",
                                                              "Heptyl", "Hexyl",
@@ -214,6 +214,16 @@ final class AbbreviationLabel {
 
             // a valid symbol token
             if ((last = findPrefix(SYMBOL_TRIE, label, i, -1)) > 0) {
+
+                // ambiguity handling, nButBu => nBut Bu vs nBu tBu
+                if (last + 1 < label.length() &&
+                    label.charAt(last-1) == 't' &&
+                    label.charAt(last) == 'B' &&
+                    label.charAt(last+1) == 'u') {
+                    // But => Bu
+                    last--;
+                }
+
                 i += (last - i);
                 // an optional number suffix e.g. O2 F3 Ph3 etc.
                 while (i < len && isDigit(label.charAt(i))) {
