@@ -1730,16 +1730,19 @@ final class StandardBondGenerator {
         }
 
         private final boolean hasMetal;
+        private final IAtomContainer mol;
 
         /**
          * Create a new comparator.
          */
         RingBondOffsetComparator(IAtomContainer mol) {
             hasMetal = hasMetal(mol);
+            this.mol = mol;
         }
 
         RingBondOffsetComparator() {
             hasMetal = false;
+            this.mol = null;
         }
 
         private static boolean hasMetal(IAtomContainer mol) {
@@ -1772,6 +1775,10 @@ final class StandardBondGenerator {
             int piBondCmp = Integer.compare(nDoubleBonds(ringa), nDoubleBonds(ringb));
             if (piBondCmp != 0) return -piBondCmp;
 
+            // the ring with more atoms with only 2 ring bonds
+            int nSimpleRing = Integer.compare(nSimpleRingAtoms(ringa), nSimpleRingAtoms(ringb));
+            if (nSimpleRing != 0) return -nSimpleRing;
+
             // order by element frequencies, all carbon rings are preferred
             int[] freqA = countLightElements(ringa);
             int[] freqB = countLightElements(ringb);
@@ -1782,6 +1789,7 @@ final class StandardBondGenerator {
                 if (elemCmp != 0) return -elemCmp;
             }
 
+
             return 0;
         }
 
@@ -1810,6 +1818,28 @@ final class StandardBondGenerator {
             return count;
         }
 
+        int nSimpleRingAtoms(IAtomContainer ring) {
+            if (mol == null) return 0;
+            int count = 0;
+            for (IAtom atom : ring.atoms()) {
+                int rcount = 0;
+
+                List<IBond> bonds = mol.getConnectedBondsList(atom);
+                if (bonds.size() == 2) {
+                    rcount = 2; // a ring atom with 2 bonds, they MUST be cyclic
+                } else {
+                    for (IBond bond : bonds) {
+                        if (bond.isInRing())
+                            rcount++;
+                    }
+                }
+
+                if (rcount == 2)
+                    count++;
+            }
+            return count;
+        }
+
         /**
          * Count the light elements (atomic number < 19) in an atom container. The count is provided
          * as a frequency vector indexed by atomic number.
