@@ -24,7 +24,7 @@
 
 package org.openscience.cdk.renderer.generators.standard;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 import org.openscience.cdk.interfaces.IAtom;
 import org.openscience.cdk.interfaces.IAtomContainer;
 import org.openscience.cdk.interfaces.IPseudoAtom;
@@ -39,12 +39,12 @@ import static org.hamcrest.CoreMatchers.is;
 import static org.hamcrest.Matchers.closeTo;
 import static org.hamcrest.Matchers.greaterThan;
 import static org.hamcrest.Matchers.lessThan;
-import static org.junit.Assert.assertThat;
+import static org.hamcrest.MatcherAssert.assertThat;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
-public class StandardAtomGeneratorTest {
+class StandardAtomGeneratorTest {
 
     private final Font                  font          = new Font("Verdana", Font.PLAIN, 12);
     private final TextOutline           element       = new TextOutline("N", font);
@@ -52,7 +52,7 @@ public class StandardAtomGeneratorTest {
     private final StandardAtomGenerator atomGenerator = new StandardAtomGenerator(font);
 
     @Test
-    public void positionHydrogenAbove() {
+    void positionHydrogenAbove() {
         TextOutline positioned = atomGenerator.positionHydrogenLabel(HydrogenPosition.Above, element, hydrogen);
         Rectangle2D elementBounds = element.getBounds();
         Rectangle2D hydrogenBounds = positioned.getBounds();
@@ -62,7 +62,7 @@ public class StandardAtomGeneratorTest {
     }
 
     @Test
-    public void positionHydrogenBelow() {
+    void positionHydrogenBelow() {
         TextOutline positioned = atomGenerator.positionHydrogenLabel(HydrogenPosition.Below, element, hydrogen);
         Rectangle2D elementBounds = element.getBounds();
         Rectangle2D hydrogenBounds = positioned.getBounds();
@@ -72,7 +72,7 @@ public class StandardAtomGeneratorTest {
     }
 
     @Test
-    public void positionHydrogenToLeft() {
+    void positionHydrogenToLeft() {
         TextOutline positioned = atomGenerator.positionHydrogenLabel(HydrogenPosition.Left, element, hydrogen);
         Rectangle2D elementBounds = element.getBounds();
         Rectangle2D hydrogenBounds = positioned.getBounds();
@@ -82,7 +82,7 @@ public class StandardAtomGeneratorTest {
     }
 
     @Test
-    public void positionHydrogenToRight() {
+    void positionHydrogenToRight() {
 
         TextOutline positioned = atomGenerator.positionHydrogenLabel(HydrogenPosition.Right, element, hydrogen);
         Rectangle2D elementBounds = element.getBounds();
@@ -93,7 +93,7 @@ public class StandardAtomGeneratorTest {
     }
 
     @Test
-    public void positionHydrogenCount() {
+    void positionHydrogenCount() {
         TextOutline hydrogenCount = new TextOutline("2", font);
         TextOutline positioned = atomGenerator.positionSubscript(hydrogen, hydrogenCount);
 
@@ -105,7 +105,7 @@ public class StandardAtomGeneratorTest {
     }
 
     @Test
-    public void positionMassLabel() {
+    void positionMassLabel() {
         TextOutline mass = new TextOutline("15", font);
         TextOutline positioned = atomGenerator.positionMassLabel(mass, element);
 
@@ -117,7 +117,7 @@ public class StandardAtomGeneratorTest {
     }
 
     @Test
-    public void positionOfChargeWhenHydrogensAreRight() {
+    void positionOfChargeWhenHydrogensAreRight() {
         // hydrogen is arbitrarily moved to ensure x/y are different from the element
         TextOutline charge = new TextOutline("+", font);
         TextOutline localHydrogen = hydrogen.translate(10, 10);
@@ -132,7 +132,7 @@ public class StandardAtomGeneratorTest {
     }
 
     @Test
-    public void positionOfChargeWhenNoHydrogensAreRight() {
+    void positionOfChargeWhenNoHydrogensAreRight() {
         // hydrogen is arbitrarily moved to ensure x/y are different from the element
         TextOutline charge = new TextOutline("+", font);
         TextOutline localHydrogen = hydrogen.translate(10, 10);
@@ -148,7 +148,7 @@ public class StandardAtomGeneratorTest {
     }
 
     @Test
-    public void positionOfChargeWhenHydrogensAreLeft() {
+    void positionOfChargeWhenHydrogensAreLeft() {
         // hydrogen is arbitrarily moved to ensure x/y are different from the element
         TextOutline charge = new TextOutline("+", font);
         TextOutline localHydrogen = hydrogen.translate(10, 10);
@@ -159,11 +159,11 @@ public class StandardAtomGeneratorTest {
         Rectangle2D chargeBounds = positioned.getBounds();
 
         assertThat(chargeBounds.getMinX(), greaterThan(elementBounds.getMinX()));
-        assertThat(chargeBounds.getCenterY(), closeTo(elementBounds.getMinY(), 0.01));
+        assertThat(chargeBounds.getCenterY(), closeTo(localHydrogen.getBounds().getMinY(), 0.01));
     }
 
     @Test
-    public void positionOfChargeWhenHydrogensAreBelow() {
+    void positionOfChargeWhenHydrogensAreBelow() {
         TextOutline charge = new TextOutline("+", font);
         TextOutline positioned = atomGenerator.positionChargeLabel(1, HydrogenPosition.Below, charge, element,
                 hydrogen.translate(0, 5));
@@ -176,7 +176,7 @@ public class StandardAtomGeneratorTest {
     }
 
     @Test
-    public void positionOfChargeWhenTwoHydrogensAreAbove() {
+    void positionOfChargeWhenTwoHydrogensAreAbove() {
         // hydrogen is arbitrarily moved to ensure x/y are different from the element
         TextOutline charge = new TextOutline("+", font);
         TextOutline localHydrogen = hydrogen.translate(10, 10);
@@ -186,12 +186,13 @@ public class StandardAtomGeneratorTest {
         Rectangle2D hydrogenBounds = localHydrogen.getBounds();
         Rectangle2D chargeBounds = positioned.getBounds();
 
-        assertThat(chargeBounds.getMinX(), greaterThan(hydrogenBounds.getMinX()));
-        assertThat(chargeBounds.getCenterY(), closeTo(hydrogenBounds.getMinY(), 0.01));
+        Rectangle2D elementBounds = element.getBounds();
+        assertThat(chargeBounds.getMinX(), greaterThan(elementBounds.getMinX()));
+        assertThat(chargeBounds.getCenterY(), closeTo(elementBounds.getMinY(), 0.01));
     }
 
     @Test
-    public void positionOfChargeWhenOneHydrogenIsAbove() {
+    void positionOfChargeWhenOneHydrogenIsAbove() {
         // hydrogen is arbitrarily moved to ensure x/y are different from the element
         TextOutline charge = new TextOutline("+", font);
         TextOutline localHydrogen = hydrogen.translate(10, 10);
@@ -206,44 +207,44 @@ public class StandardAtomGeneratorTest {
     }
 
     @Test
-    public void generateWithNoAdjuncts() {
-        AtomSymbol symbol = atomGenerator.generatePeriodicSymbol(7, 0, -1, 0, 0, HydrogenPosition.Right);
+    void generateWithNoAdjuncts() {
+        AtomSymbol symbol = atomGenerator.generatePeriodicSymbol(7, 0, -1, 0, 0, HydrogenPosition.Right, null);
         assertThat(symbol.getOutlines().size(), is(1));
     }
 
     @Test
-    public void generateWithHydrogenAdjunct() {
-        AtomSymbol symbol = atomGenerator.generatePeriodicSymbol(7, 1, -1, 0, 0, HydrogenPosition.Right);
+    void generateWithHydrogenAdjunct() {
+        AtomSymbol symbol = atomGenerator.generatePeriodicSymbol(7, 1, -1, 0, 0, HydrogenPosition.Right, null);
         assertThat(symbol.getOutlines().size(), is(2));
     }
 
     @Test
-    public void generateWithHydrogenAndCountAdjunct() {
-        AtomSymbol symbol = atomGenerator.generatePeriodicSymbol(7, 2, -1, 0, 0, HydrogenPosition.Right);
+    void generateWithHydrogenAndCountAdjunct() {
+        AtomSymbol symbol = atomGenerator.generatePeriodicSymbol(7, 2, -1, 0, 0, HydrogenPosition.Right, null);
         assertThat(symbol.getOutlines().size(), is(3));
     }
 
     @Test
-    public void generateWithMassAdjunct() {
-        AtomSymbol symbol = atomGenerator.generatePeriodicSymbol(7, 0, 15, 0, 0, HydrogenPosition.Right);
+    void generateWithMassAdjunct() {
+        AtomSymbol symbol = atomGenerator.generatePeriodicSymbol(7, 0, 15, 0, 0, HydrogenPosition.Right, null);
         assertThat(symbol.getOutlines().size(), is(2));
     }
 
     @Test
-    public void generateWithChargeAdjunct() {
-        AtomSymbol symbol = atomGenerator.generatePeriodicSymbol(7, 0, -1, 1, 0, HydrogenPosition.Right);
+    void generateWithChargeAdjunct() {
+        AtomSymbol symbol = atomGenerator.generatePeriodicSymbol(7, 0, -1, 1, 0, HydrogenPosition.Right, null);
         assertThat(symbol.getOutlines().size(), is(2));
     }
 
     @Test
-    public void generateWithRadicalAdjunct() {
-        AtomSymbol symbol = atomGenerator.generatePeriodicSymbol(7, 0, -1, 0, 1, HydrogenPosition.Right);
+    void generateWithRadicalAdjunct() {
+        AtomSymbol symbol = atomGenerator.generatePeriodicSymbol(7, 0, -1, 0, 1, HydrogenPosition.Right, null);
         assertThat(symbol.getOutlines().size(), is(2));
     }
 
     @Test
-    public void hydrogenDodgesMassLabel() {
-        AtomSymbol symbol = atomGenerator.generatePeriodicSymbol(7, 1, 15, 0, 0, HydrogenPosition.Left);
+    void hydrogenDodgesMassLabel() {
+        AtomSymbol symbol = atomGenerator.generatePeriodicSymbol(7, 1, 15, 0, 0, HydrogenPosition.Left, null);
         List<Shape> outlines = symbol.getOutlines();
         assertThat(outlines.size(), is(3));
         Shape hydrogenShape = outlines.get(1);
@@ -252,8 +253,8 @@ public class StandardAtomGeneratorTest {
     }
 
     @Test
-    public void hydrogenAndHydrogenCountDodgesMassLabel() {
-        AtomSymbol symbol = atomGenerator.generatePeriodicSymbol(7, 2, 15, 0, 0, HydrogenPosition.Left);
+    void hydrogenAndHydrogenCountDodgesMassLabel() {
+        AtomSymbol symbol = atomGenerator.generatePeriodicSymbol(7, 2, 15, 0, 0, HydrogenPosition.Left, null);
         List<Shape> outlines = symbol.getOutlines();
         assertThat(outlines.size(), is(4));
         Shape hydrogenShape = outlines.get(1);
@@ -270,8 +271,8 @@ public class StandardAtomGeneratorTest {
     }
 
     @Test
-    public void hydrogenCountDodgesElement() {
-        AtomSymbol symbol = atomGenerator.generatePeriodicSymbol(7, 2, -1, 0, 0, HydrogenPosition.Left);
+    void hydrogenCountDodgesElement() {
+        AtomSymbol symbol = atomGenerator.generatePeriodicSymbol(7, 2, -1, 0, 0, HydrogenPosition.Left, null);
         List<Shape> outlines = symbol.getOutlines();
         assertThat(outlines.size(), is(3));
         Shape elementShape = outlines.get(0);
@@ -283,8 +284,8 @@ public class StandardAtomGeneratorTest {
     }
 
     @Test
-    public void hydrogenDoesNotNeedToDodge() {
-        AtomSymbol symbol = atomGenerator.generatePeriodicSymbol(7, 1, -1, 0, 0, HydrogenPosition.Left);
+    void hydrogenDoesNotNeedToDodge() {
+        AtomSymbol symbol = atomGenerator.generatePeriodicSymbol(7, 1, -1, 0, 0, HydrogenPosition.Left, null);
         List<Shape> outlines = symbol.getOutlines();
         assertThat(outlines.size(), is(2));
         Shape elementShape = outlines.get(0);
@@ -293,121 +294,121 @@ public class StandardAtomGeneratorTest {
     }
 
     @Test
-    public void anion() throws Exception {
+    void anion() throws Exception {
         assertThat(StandardAtomGenerator.chargeAdjunctText(-1, 0), is("−"));
     }
 
     @Test
-    public void cation() throws Exception {
+    void cation() throws Exception {
         assertThat(StandardAtomGenerator.chargeAdjunctText(1, 0), is("+"));
     }
 
     @Test
-    public void dianion() throws Exception {
+    void dianion() throws Exception {
         assertThat(StandardAtomGenerator.chargeAdjunctText(-2, 0), is("2−"));
     }
 
     @Test
-    public void dication() throws Exception {
+    void dication() throws Exception {
         assertThat(StandardAtomGenerator.chargeAdjunctText(2, 0), is("2+"));
     }
 
     @Test
-    public void radical() throws Exception {
+    void radical() throws Exception {
         assertThat(StandardAtomGenerator.chargeAdjunctText(0, 1), is("•"));
     }
 
     @Test
-    public void diradical() throws Exception {
+    void diradical() throws Exception {
         assertThat(StandardAtomGenerator.chargeAdjunctText(0, 2), is("2•"));
     }
 
     @Test
-    public void diradicalCation() throws Exception {
+    void diradicalCation() throws Exception {
         assertThat(StandardAtomGenerator.chargeAdjunctText(1, 2), is("(2•)+"));
     }
 
     @Test
-    public void radicalAndAnion() throws Exception {
+    void radicalAndAnion() throws Exception {
         assertThat(StandardAtomGenerator.chargeAdjunctText(-1, 1), is("(•)−"));
     }
 
     @Test
-    public void accessNullPseudoLabel() throws Exception {
+    void accessNullPseudoLabel() throws Exception {
         IPseudoAtom atom = mock(IPseudoAtom.class);
         when(atom.getLabel()).thenReturn(null);
         assertThat(StandardAtomGenerator.accessPseudoLabel(atom, "*"), is("*"));
     }
 
     @Test
-    public void accessEmptyPseudoLabel() throws Exception {
+    void accessEmptyPseudoLabel() throws Exception {
         IPseudoAtom atom = mock(IPseudoAtom.class);
         when(atom.getLabel()).thenReturn("");
         assertThat(StandardAtomGenerator.accessPseudoLabel(atom, "*"), is("*"));
     }
 
     @Test
-    public void accessRgroupPseudoLabel() throws Exception {
+    void accessRgroupPseudoLabel() throws Exception {
         IPseudoAtom atom = mock(IPseudoAtom.class);
         when(atom.getLabel()).thenReturn("R1");
         assertThat(StandardAtomGenerator.accessPseudoLabel(atom, "*"), is("R1"));
     }
 
     @Test
-    public void numberedRgroupSymbol() {
-        AtomSymbol atomSymbol = atomGenerator.generatePseudoSymbol("R1", HydrogenPosition.Right);
+    void numberedRgroupSymbol() {
+        AtomSymbol atomSymbol = atomGenerator.generatePseudoSymbol("R1", HydrogenPosition.Right, null);
         List<Shape> shapes = atomSymbol.getOutlines();
         assertThat(shapes.size(), is(2));
     }
 
     @Test
-    public void RgroupSymbol2A() {
-        AtomSymbol atomSymbol = atomGenerator.generatePseudoSymbol("R2a", HydrogenPosition.Right);
+    void RgroupSymbol2A() {
+        AtomSymbol atomSymbol = atomGenerator.generatePseudoSymbol("R2a", HydrogenPosition.Right, null);
         List<Shape> shapes = atomSymbol.getOutlines();
         assertThat(shapes.size(), is(2));
     }
 
     @Test
-    public void RgroupSymbolY() {
-        AtomSymbol atomSymbol = atomGenerator.generatePseudoSymbol("Y1a2", HydrogenPosition.Right);
+    void RgroupSymbolY() {
+        AtomSymbol atomSymbol = atomGenerator.generatePseudoSymbol("Y1a2", HydrogenPosition.Right, null);
         List<Shape> shapes = atomSymbol.getOutlines();
         assertThat(shapes.size(), is(1));
     }
 
     @Test
-    public void RgroupSymbolPrime() {
-        AtomSymbol atomSymbol = atomGenerator.generatePseudoSymbol("R'", HydrogenPosition.Right);
+    void RgroupSymbolPrime() {
+        AtomSymbol atomSymbol = atomGenerator.generatePseudoSymbol("R'", HydrogenPosition.Right, null);
         List<Shape> shapes = atomSymbol.getOutlines();
         assertThat(shapes.size(), is(2));
     }
 
     @Test
-    public void RgroupSymbolNumberedPrime() {
-        AtomSymbol atomSymbol = atomGenerator.generatePseudoSymbol("R2'", HydrogenPosition.Right);
+    void RgroupSymbolNumberedPrime() {
+        AtomSymbol atomSymbol = atomGenerator.generatePseudoSymbol("R2'", HydrogenPosition.Right, null);
         List<Shape> shapes = atomSymbol.getOutlines();
         assertThat(shapes.size(), is(3));
     }
 
     @Test
-    public void pseudoSymbol() {
-        AtomSymbol atomSymbol = atomGenerator.generatePseudoSymbol("Protein", HydrogenPosition.Right);
+    void pseudoSymbol() {
+        AtomSymbol atomSymbol = atomGenerator.generatePseudoSymbol("Protein", HydrogenPosition.Right, null);
         List<Shape> shapes = atomSymbol.getOutlines();
         assertThat(shapes.size(), is(1));
     }
 
     @Test
-    public void generatesRgroupPseudoAtom() {
+    void generatesRgroupPseudoAtom() {
         IAtomContainer container = mock(IAtomContainer.class);
         IPseudoAtom atom = mock(IPseudoAtom.class);
         when(atom.getLabel()).thenReturn("R1");
-        AtomSymbol    atomSymbol = atomGenerator.generateSymbol(container, atom, HydrogenPosition.Left, new RendererModel());
+        AtomSymbol    atomSymbol = atomGenerator.generateSymbol(container, atom, HydrogenPosition.Left, null);
         List<Shape>   shapes     = atomSymbol.getOutlines();
         assertThat(shapes.size(), is(2));
     }
 
     // the mass symbol is not displayed
     @Test
-    public void generatesCarbon12() {
+    void generatesCarbon12() {
         IAtomContainer container = mock(IAtomContainer.class);
         IAtom atom = mock(IAtom.class);
         when(atom.getAtomicNumber()).thenReturn(6);
@@ -423,7 +424,7 @@ public class StandardAtomGeneratorTest {
     }
 
     @Test
-    public void generatesCarbon13() {
+    void generatesCarbon13() {
         IAtomContainer container = mock(IAtomContainer.class);
         IAtom atom = mock(IAtom.class);
         when(atom.getAtomicNumber()).thenReturn(6);
@@ -438,7 +439,7 @@ public class StandardAtomGeneratorTest {
     }
 
     @Test
-    public void nullMassNumber() {
+    void nullMassNumber() {
         IAtomContainer container = mock(IAtomContainer.class);
         IAtom atom = mock(IAtom.class);
         when(atom.getAtomicNumber()).thenReturn(6);
@@ -451,7 +452,7 @@ public class StandardAtomGeneratorTest {
     }
 
     @Test
-    public void nullHydrogenCount() {
+    void nullHydrogenCount() {
         IAtomContainer container = mock(IAtomContainer.class);
         IAtom atom = mock(IAtom.class);
         when(atom.getAtomicNumber()).thenReturn(6);
@@ -466,7 +467,7 @@ public class StandardAtomGeneratorTest {
     }
 
     @Test
-    public void nullFormatCharge() {
+    void nullFormatCharge() {
         IAtomContainer container = mock(IAtomContainer.class);
         IAtom atom = mock(IAtom.class);
         when(atom.getAtomicNumber()).thenReturn(6);
@@ -481,7 +482,7 @@ public class StandardAtomGeneratorTest {
     }
 
     @Test
-    public void nullAtomicNumber() {
+    void nullAtomicNumber() {
         IAtomContainer container = mock(IAtomContainer.class);
         IAtom atom = mock(IAtom.class);
         when(atom.getAtomicNumber()).thenReturn(null);
@@ -498,7 +499,7 @@ public class StandardAtomGeneratorTest {
     }
 
     @Test
-    public void nullAtomicNumberAndSymbol() {
+    void nullAtomicNumberAndSymbol() {
         IAtomContainer container = mock(IAtomContainer.class);
         IAtom atom = mock(IAtom.class);
         when(atom.getAtomicNumber()).thenReturn(null);
@@ -513,7 +514,7 @@ public class StandardAtomGeneratorTest {
     }
 
     @Test
-    public void unpairedElectronsAreAccessed() {
+    void unpairedElectronsAreAccessed() {
         IAtomContainer container = mock(IAtomContainer.class);
         IAtom atom = mock(IAtom.class);
         when(atom.getAtomicNumber()).thenReturn(6);
