@@ -43,7 +43,6 @@ import java.util.List;
  * Base class for test classes that test {@link IAtomContainerGenerator}s.
  *
  * @author     maclean
- * @cdk.module test-renderbasic
  */
 abstract class AbstractGeneratorTest {
 
@@ -79,7 +78,7 @@ abstract class AbstractGeneratorTest {
 
     <T> boolean containsParameterType(List<IGeneratorParameter<?>> list, Class<T> type) {
         for (IGeneratorParameter<?> item : list) {
-            if (item.getClass().getName().equals(type.getName())) return true;
+            if (item.getClass().isAssignableFrom(type)) return true;
         }
         return false;
     }
