@@ -40,15 +40,12 @@ import org.openscience.cdk.interfaces.IElement;
 import org.openscience.cdk.interfaces.IMolecularFormula;
 import org.openscience.cdk.io.formats.IResourceFormat;
 import org.openscience.cdk.io.formats.ShelXFormat;
-import org.openscience.cdk.tools.FormatStringBuffer;
 import org.openscience.cdk.tools.manipulator.MolecularFormulaManipulator;
 
 /**
  * <p>Serializes a MoleculeSet or a Molecule object to ShelX code.
  * The output can be read with Platon.
  *
- * @cdk.module  extra
- * @cdk.githash
  * @cdk.iooptions
  *
  * @author Egon Willighagen
@@ -90,7 +87,7 @@ public class ShelXWriter extends DefaultChemObjectWriter {
     }
 
     @Override
-    public void setWriter(Writer out) throws CDKException {
+    public void setWriter(Writer out) {
         if (out instanceof BufferedWriter) {
             writer = (BufferedWriter) out;
         } else {
@@ -99,7 +96,7 @@ public class ShelXWriter extends DefaultChemObjectWriter {
     }
 
     @Override
-    public void setWriter(OutputStream output) throws CDKException {
+    public void setWriter(OutputStream output) {
         setWriter(new OutputStreamWriter(output));
     }
 
@@ -139,7 +136,7 @@ public class ShelXWriter extends DefaultChemObjectWriter {
     private void writeCrystal(ICrystal crystal) {
 
         Object title = crystal.getTitle();
-        if (title != null && title.toString().trim().length() > 0) {
+        if (title != null && !title.toString().trim().isEmpty()) {
             writeln("TITL " + title.toString().trim());
         } else {
             writeln("TITL Produced with CDK (http://cdk.sf.net/)");
@@ -153,7 +150,7 @@ public class ShelXWriter extends DefaultChemObjectWriter {
         double alpha = Math.toDegrees(b.angle(c));
         double beta = Math.toDegrees(a.angle(c));
         double gamma = Math.toDegrees(a.angle(b));
-        FormatStringBuffer format = new FormatStringBuffer("%7.5lf");
+        FormatStringBuilder format = new FormatStringBuilder("%7.5lf");
         write("CELL " + format.reset("%7.5f").format(1.54184).toString() + "   ");
         write(format.reset("%8.5f").format(alength) + "  ");
         write(format.reset("%8.5f").format(blength) + "  ");
@@ -173,15 +170,15 @@ public class ShelXWriter extends DefaultChemObjectWriter {
             writeln("SYMM  1/2-X   ,    -Y   , 1/2+Z");
         }
         //        MFAnalyser mfa = new MFAnalyser(crystal);
-        String elemNames = "";
-        String elemCounts = "";
+        StringBuilder elemNames = new StringBuilder();
+        StringBuilder elemCounts = new StringBuilder();
         IMolecularFormula formula = MolecularFormulaManipulator.getMolecularFormula(crystal);
         List<IElement> asortedElements = MolecularFormulaManipulator.elements(formula);
         for (IElement element : asortedElements) {
             String symbol = element.getSymbol();
-            elemNames += symbol + "    ".substring(symbol.length());
+            elemNames.append(symbol).append("    ".substring(symbol.length()));
             String countS = Integer.valueOf(MolecularFormulaManipulator.getElementCount(formula, element)).toString();
-            elemCounts += countS + "    ".substring(countS.length());
+            elemCounts.append(countS).append("    ".substring(countS.length()));
         }
         writeln("SFAC  " + elemNames);
         writeln("UNIT  " + elemCounts);
