@@ -131,16 +131,6 @@ public final class RdfileReader implements Closeable, Iterator<RdfileRecord> {
         this(new InputStreamReader(in, StandardCharsets.UTF_8), chemObjectBuilder, continueOnError);
     }
 
-    /**
-     * Creates a new RdfileReader instance with the given InputStream and IChemObjectBuilder.
-     *
-     * @param reader the Reader providing the RDfile data
-     * @param chemObjectBuilder the IChemObjectBuilder for creating CDK objects
-     */
-    public RdfileReader(Reader reader, IChemObjectBuilder chemObjectBuilder) {
-        this(reader, chemObjectBuilder, true);
-    }
-
     /**
      * Creates a new RdfileReader instance with the given InputStream and IChemObjectBuilder.
      * <p>
@@ -159,6 +149,8 @@ public final class RdfileReader implements Closeable, Iterator<RdfileRecord> {
             this.bufferedReader = new BufferedReader(reader);
         }
 
+        if (chemObjectBuilder == null)
+            throw new NullPointerException("A ChemObjectBuilder must be provided or available on the class path!");
         this.chemObjectBuilder = chemObjectBuilder;
         this.continueOnError = continueOnError;
     }
